# Copyright 2019 Tobias Höfer
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# =============================================================================
"""Image detection models API"""
from dnnlab.input_pipeline import img
from dnnlab.input_pipeline import img_img
from dnnlab.input_pipeline import img_label
from dnnlab.input_pipeline import yolo
from dnnlab.input_pipeline.triplet_net import TripletDataset
from dnnlab.input_pipeline import augmentation